@@ -1,11 +1,11 @@
 from .registered_task import RegisteredTask, MockTask, PrintTask
 from .taskqueue import (
   TaskQueue, GreenTaskQueue, MockTaskQueue, LocalTaskQueue, 
-  multiprocess_upload
+  multiprocess_upload, QueueEmpty, totask
 )
 from .secrets import (
   QUEUE_NAME, TEST_QUEUE_NAME, QUEUE_TYPE, 
   PROJECT_NAME, AWS_DEFAULT_REGION
 )
 
-__version__ = '0.14.0'
\ No newline at end of file
+__version__ = '0.14.1'
\ No newline at end of file
